# Generated by Django 2.1.1 on 2018-10-02 15:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('list_based_flavorpack', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='processingparameters',
            name='list_based_region',
            field=models.ForeignKey(help_text='A key-value pair object meant to hold parameters used for processing classes.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='processing_parameters', to='list_based_flavorpack.ListBasedRegion', verbose_name='Processing Class Parameter'),
        ),
    ]
